Gemeinde Adressverwaltung GUI: Gemeinde_Modelle.FamilieGruppeSchlank Klassenreferenz

Gemeinde Adressverwaltung GUI

Öffentliche Methoden | Statische öffentliche Attribute | Aufstellung aller Elemente
Gemeinde_Modelle.FamilieGruppeSchlank Klassenreferenz
Klassendiagramm für Gemeinde_Modelle.FamilieGruppeSchlank:
[Legende]
Zusammengehörigkeiten von Gemeinde_Modelle.FamilieGruppeSchlank:
[Legende]

## Öffentliche Methoden
def | __init__ (self, id=None, holen=False)
def | __str__ (self)

## Statische öffentliche Attribute
| R_familie = Relation('familie_id', Familie, 'id')
| R_gruppe = Relation('gruppe_kurz_bez', Gruppe, 'kurz_bez')

Die Dokumentation für diese Klasse wurde erzeugt aufgrund der Datei:

- Gemeinde_Modelle.py